@@ -1,8 +1,8 @@
 #!/usr/local/bin/perl
 # $File: //member/autrijus/Encode-HanConvert/bin/g2b.pl $ $Author: autrijus $
-# $Revision: #6 $ $Change: 3834 $ $DateTime: 2003/01/25 13:41:45 $
+# $Revision: #7 $ $Change: 3922 $ $DateTime: 2003/01/27 20:49:47 $
 
-$VERSION = '0.08';
+$VERSION = '0.09';
 
 =head1 NAME
 
@@ -64,7 +64,7 @@ while (<>) {
 }
 
 use constant MAP => DICT && {
-    map { UTF8 ? Encode::decode(big5 => $_) : $_ }
+    map { UTF8 ? Encode::decode(big5 => $_) : $_ } (
 'A' => 'H',
 'AӺ' => 'HӺ',
 'EEk' => 'EE',
@@ -90,7 +90,7 @@ use constant MAP => DICT && {
 'ı׶' => '',
 '' => '',
 'y' => '',
-'\' => '',
+'\\' => '',
 ']' => 'c',
 'vFL' => 'jL',
 '~Ӫ' => '~hŶ',
@@ -178,7 +178,7 @@ use constant MAP => DICT && {
 'p' => 'p⾹',
 '}i' => '}',
 '' => '^',
-'' => '\',
+'' => '\\',
 '˷' => '˾`',
 'Ծ' => 'Ծ',
 'M˳n' => 'n]',
@@ -308,8 +308,8 @@ use constant MAP => DICT && {
 '|' => '|',
 '' => '{',
 '' => '',
-'f' => '\f',
-'۰' => '\\۰',
+'f' => '\\f',
+'۰' => '\\\\۰',
 'x' => '',
 'ƾھ' => 'ըѽվ',
 'Ȧs' => 'ws',
@@ -366,7 +366,7 @@ use constant MAP => DICT && {
 'Iܹ' => 'Tܹ',
 'Jg' => 'E',
 'v' => 'OP',
-'Ūd' => 'd\Ū',
+'Ūd' => 'd\\Ū',
 'B' => '',
 'eӧg' => 'ڮӧg',
 'Ʀ' => '',
